@@ -1,7 +1,7 @@
 import os
 from collections import OrderedDict
 
-__VERSION__ = "1.7.1"
+__VERSION__ = "1.9.0"
 __version__ = __VERSION__
 
 ASSAY_LIST = [
@@ -15,7 +15,7 @@ ASSAY_LIST = [
     'hla',
     'capture_rna',
     'citeseq',
-    'tcr_fl',
+    'sweetseq'
 ]
 
 ROOT_PATH = os.path.dirname(__file__)
@@ -25,16 +25,21 @@ RELEASED_ASSAYS = ['rna', 'vdj', 'tag', 'dynaseq', 'snp', 'capture_virus']
 # argument help
 HELP_DICT = {
     'match_dir': 'Match celescope scRNA-Seq directory.',
-    'gene_list': 'Required. Gene list file, one gene symbol per line. Only results of these genes are reported.',
-    'genomeDir': 'Required. Genome directory after running `celescope rna mkref`.',
+    'gene_list': 'Required. Gene list file, one gene symbol per line. Only results of these genes are reported. Conflict with `--panel`',
+    'genomeDir': 'Required. Genome directory after running `celescope {assay} mkref`.',
     'thread': 'Thread to use.',
     'debug': 'If this argument is used, celescope may output addtional file for debugging.',
     'fasta': 'Required. Genome fasta file. Use absolute path or relative path to `genomeDir`.',
     'outdir': 'Output directory.',
     'matrix_dir': 'Match celescope scRNA-Seq matrix directory.',
-    'panel': 'The prefix of bed file in `celescope/data/snp/panel/`, such as `lung_1`.',
+    'panel': 'The prefix of bed file in `celescope/data/snp/panel/`, such as `lung_1`. Conflict with `--gene_list`',
     'virus_genomeDir': 'Required. Virus genome directory after running `celescope capture_virus mkref`.',
-    'threshold_method': 'One of [otsu, auto, hard, none].'
+    'threshold_method': 'One of [otsu, auto, hard, none].',
+    'tsne_file': 'match_dir t-SNE coord file. Do not required when `--match_dir` is provided.',
+    'df_marker_file': 'match_dir df_marker_file. Not required when `--match_dir` is provided.',
+    'cell_calling_method': 'Default `EmptyDrops_CR`. Choose from [`auto`, `EmptyDrops_CR`]',
+    'additional_param': 'Additional parameters for the called software. Need to be enclosed in quotation marks. For example, `--{software}_param "--param1 value1 --param2 value2"`.',
+    
 }
 
 # report metrics help
