@@ -4,10 +4,10 @@ from celescope.tools.multi import Multi
 
 class Multi_fusion(Multi):
     """
-    Features
+    ## Features
     - Generate multi-sample scripts.
 
-    Usage
+    ## Usage
     ```
     multi_fusion\\
     --mapfile ./fusion.mapfile\\
@@ -51,10 +51,11 @@ class Multi_fusion(Multi):
     def analysis_fusion(self, sample):
         step = 'analysis_fusion'
         cmd_line = self.get_cmd_line(step, sample)
-        filter_tsne_file = f'{self.outdir_dic[sample]["filter_fusion"]}/{sample}_filtered_UMI_tsne.csv'
+        filter_umi_file = f'{self.outdir_dic[sample]["filter_fusion"]}/{sample}_filtered_UMI.csv'
         cmd = (
             f'{cmd_line} '
-            f'--filter_tsne_file {filter_tsne_file} '
+            f'--match_dir {self.col4_dict[sample]} '
+            f'--filter_umi_file {filter_umi_file} '
         )
         self.process_cmd(cmd, step, sample, m=5, x=1)
 
