@@ -1,5 +1,5 @@
 
-import celescope.tools.utils as utils
+from celescope.tools import utils
 from celescope.__init__ import HELP_DICT
 from celescope.tools.step import Step, s_common
 from celescope.rna.mkref import Mkref_rna
@@ -7,19 +7,19 @@ from celescope.rna.mkref import Mkref_rna
 
 class Variant_calling(Step):
     """
-    Features
+    ## Features
     - Perform variant calling at single cell level.
 
-    Output
-
-    - `{sample}_norm.vcf` Normalized vcf file.
+    ## Output
+    - `{sample}_raw.vcf` Variants are called with bcftools default settings.
+    - `{sample}_norm.vcf` Indels are left-aligned and normalized. See https://samtools.github.io/bcftools/bcftools.html#norm for more details.
     """
 
     def __init__(self, args):
         Step.__init__(self, args)
 
         # set
-        self.barcodes, _num = utils.read_barcode_file(args.match_dir)
+        self.barcodes, _num = utils.get_barcode_from_match_dir(args.match_dir)
         self.fasta = Mkref_rna.parse_genomeDir(args.genomeDir)['fasta']
         self.df_vcf = None
         self.panel = args.panel
@@ -108,7 +108,8 @@ class Variant_calling(Step):
         self.SplitNCigarReads()
         self.call_variants()
         self.bcftools_norm()
-        self._clean_up()
+
+    
 
 
 @utils.add_log
