@@ -8,7 +8,7 @@ from itertools import combinations, product
 import pysam
 from xopen import xopen
 
-import celescope.tools.utils as utils
+from celescope.tools import utils
 from celescope.tools.__init__ import __PATTERN_DICT__
 from celescope.__init__ import ROOT_PATH
 from celescope.tools.step import Step, s_common
@@ -258,14 +258,14 @@ class Chemistry():
 
         """
 
-        if seq[65:69] == "TTTT":
-            return "scopeV2.0.1"
-
         linker_v2 = get_seq_str(seq, self.pattern_dict_v2["L"])
         bool_valid, _, _ = check_seq_mismatch(
             [linker_v2], self.linker_1_v2_set_list, self.linker_1_v2_mismatch_list)
         if bool_valid:
-            return "scopeV2.1.1"
+            if seq[65:69] == "TTTT":
+                return "scopeV2.0.1"
+            else:
+                return "scopeV2.1.1"
 
         bool_valid, _, _ = check_seq_mismatch(
             [linker_v2], self.linker_4_v2_set_list, self.linker_4_v2_mismatch_list)
@@ -315,7 +315,7 @@ class Chemistry():
 
 class Barcode(Step):
     """
-    Features
+    ## Features
 
     - Demultiplex barcodes.
     - Filter invalid R1 reads, which includes:
@@ -324,7 +324,7 @@ class Barcode(Step):
         - Reads without polyT: the number of T bases in the defined polyT region is less than 10.
         - Low quality reads: low sequencing quality in barcode and UMI regions.
 
-    Output
+    ## Output
 
     - `01.barcode/{sample}_2.fq(.gz)` Demultiplexed R2 reads. Barcode and UMI are contained in the read name. The format of 
     the read name is `{barcode}_{UMI}_{read ID}`.
@@ -362,6 +362,7 @@ class Barcode(Step):
         self.allowNoLinker = args.allowNoLinker
         self.nopolyT = args.nopolyT  # true == output nopolyT reads
         self.noLinker = args.noLinker
+        self.output_R1 = args.output_R1
 
         # out file
         if args.gzip:
@@ -369,12 +370,13 @@ class Barcode(Step):
         else:
             suffix = ""
         self.out_fq2 = f'{self.out_prefix}_2.fq{suffix}'
+        self.out_fq1 = f'{self.out_prefix}_1.fq{suffix}'
         if self.nopolyT:
-            self.nopolyT_1 = f'{self.out_prefix}/noPolyT_1.fq'
-            self.nopolyT_2 = f'{self.out_prefix}/noPolyT_2.fq'
+            self.nopolyT_1 = f'{self.out_prefix}_noPolyT_1.fq'
+            self.nopolyT_2 = f'{self.out_prefix}_noPolyT_2.fq'
         if self.noLinker:
-            self.noLinker_1 = f'{self.out_prefix}/noLinker_1.fq'
-            self.noLinker_2 = f'{self.out_prefix}/noLinker_2.fq'
+            self.noLinker_1 = f'{self.out_prefix}_noLinker_1.fq'
+            self.noLinker_2 = f'{self.out_prefix}_noLinker_2.fq'
 
     @utils.add_log
     def run(self):
@@ -392,9 +394,11 @@ class Barcode(Step):
                 filter
                 write valid R2 read to file
         """
-
+        if self.output_R1:
+            out_fq1 = xopen(self.out_fq1, 'w')
         out_fq2 = xopen(self.out_fq2, 'w')
 
+
         if self.nopolyT:
             fh1_without_polyT = xopen(self.nopolyT_1, 'w')
             fh2_without_polyT = xopen(self.nopolyT_2, 'w')
@@ -502,6 +506,9 @@ class Barcode(Step):
                     self.umi_qual_Counter.update(C_U_quals_ascii[C_len:])
 
                     out_fq2.write(f'@{cb}_{umi}_{self.total_num}\n{seq2}\n+\n{qual2}\n')
+                    if self.output_R1:
+                        out_fq1.write(f'@{cb}_{umi}_{self.total_num}\n{seq1}\n+\n{qual1}\n')
+                        
             self.run.logger.info(self.fq1_list[i] + ' finished.')
         out_fq2.close()
 
@@ -629,6 +636,11 @@ lowQual will be regarded as low-quality bases.',
         help="Output gzipped fastq files.",
         action='store_true'
     )
+    parser.add_argument(
+        '--output_R1',
+        help="Output valid R1 reads.",
+        action='store_true'
+    )
     if sub_program:
         parser.add_argument('--fq1', help='R1 fastq file. Multiple files are separated by comma.', required=True)
         parser.add_argument('--fq2', help='R2 fastq file. Multiple files are separated by comma.', required=True)
