@@ -8,7 +8,7 @@ import subprocess
 
 from jinja2 import Environment, FileSystemLoader, select_autoescape
 
-import celescope.tools.utils as utils
+from celescope.tools import utils
 from celescope.__init__ import HELP_DICT
 
 
@@ -25,7 +25,6 @@ def s_common(parser):
     """subparser common arguments
     """
     parser.add_argument('--outdir', help='Output diretory.', required=True)
-    parser.add_argument('--assay', help='Assay name.', required=True)
     parser.add_argument('--sample', help='Sample name.', required=True)
     parser.add_argument('--thread', help=HELP_DICT['thread'], default=4)
     parser.add_argument('--debug', help=HELP_DICT['debug'], action='store_true')
@@ -45,10 +44,11 @@ class Step:
         self.args = args
         self.outdir = args.outdir
         self.sample = args.sample
-        self.assay = args.assay
+        self.assay = args.subparser_assay
         self.thread = int(args.thread)
         self.debug = args.debug
         self.out_prefix = f'{self.outdir}/{self.sample}'
+        self.display_title = display_title
 
         # important! make outdir before path_dict because path_dict use relative path.
         utils.check_mkdir(self.outdir)
@@ -88,12 +88,13 @@ class Step:
         # out file
         self.__stat_file = f'{self.outdir}/stat.txt'
 
-    def add_metric(self, name, value, total=None, help_info=None, display=None):
+    def add_metric(self, name, value, total=None, help_info=None, display=None, show=True):
         '''
         add metric to metric_list
         
         Args
             display: controls how to display the metric in HTML report.
+            show: whether to add to .data.json, show the metric in HTML report and stat.txt.
         '''
 
         name = cap_str_except_preposition(name)
@@ -118,17 +119,19 @@ class Step:
                 "fraction": fraction,
                 "display": display,
                 "help_info": help_info,
+                "show": show,
             }
         )
 
     def _write_stat(self):
         with open(self.__stat_file, 'w') as writer:
             for metric in self.__metric_list:
-                name = metric['name']
-                display = metric['display']
+                if metric['show']:
+                    name = metric['name']
+                    display = metric['display']
 
-                line = f'{name}: {display}'
-                writer.write(line + '\n')
+                    line = f'{name}: {display}'
+                    writer.write(line + '\n')
 
     def _dump_content(self):
         '''dump content to json file
@@ -149,7 +152,11 @@ class Step:
     def _add_content_data(self):
         step_summary = {}
         step_summary['display_title'] = self._display_title
-        step_summary['metric_list'] = self.__metric_list
+        metric_list = []
+        for metric in self.__metric_list:
+            if metric['show']:
+                metric_list.append(metric)
+        step_summary['metric_list'] = metric_list
         step_summary['help_content'] = self.__help_content
         self.__content_dict['data'][self._step_summary_name].update(step_summary)
 
@@ -219,6 +226,12 @@ class Step:
         self.debug_subprocess_call.logger.debug(cmd)
         subprocess.check_call(cmd, shell=True)
 
+    def get_metric_list(self):
+        return self.__metric_list
+
+    def set_metric_list(self, metric_list):
+        self.__metric_list = metric_list
+
     @abc.abstractmethod
     def run(self):
         sys.exit('Please implement run() method.')
